@@ -101,8 +101,8 @@ class Domoticz(IPlugin):
 #				log.msg("*********************************************  : ")
 #				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				for rt in jsonreq['result'] :
-					log.msg("*** jsonreq - NT - idx   :  %s" % (rt['idx']))
-					log.msg("*** jsonreq - NT - rs - rt  - idx  : %s    %s " % (int(rs['idx']),int(rt['idx']))
+					log.msg("*** jsonreq - NT-rt - idx   :  %s" % (rt['idx']))
+					log.msg("*** jsonreq - NT-rs - idx   :  %s" % (rs['idx']))
 
 					if int(rs['idx']) == int(rt['idx']):
 						log.msg("**************************  jsonreq - idx   :  %s" % (rt['idx']))
